@@ -1,9 +1,9 @@
 /*  ADCD - A Diminutive CD player for GNU/Linux
-    Copyright (C) 2004, 2005, 2006 Antonio Diaz Diaz.
+    Copyright (C) 2004, 2005, 2006, 2007 Antonio Diaz Diaz.
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
     Return values: 0 for a normal exit, 1 for environmental problems
@@ -37,8 +36,9 @@
 namespace {
 
 const char * invocation_name = 0;
-const char * const program_name    = "Adcd";
-const char * const program_year    = "2006";
+const char * const Program_name    = "Adcd";
+const char * const program_name    = "adcd";
+const char * const program_year    = "2007";
 
 
 void show_error( const char * msg, const int errcode = 0, const bool help = false ) throw()
@@ -56,7 +56,7 @@ void show_error( const char * msg, const int errcode = 0, const bool help = fals
 
 void show_help() throw()
   {
-  std::printf( "%s - A Diminutive CD player for GNU/Linux.\n", program_name );
+  std::printf( "%s - A Diminutive CD player for GNU/Linux.\n", Program_name );
   std::printf( "If invoked without options enters interactive mode.\n" );
   std::printf( "\nUsage: %s [options] [device]\n", invocation_name );
   std::printf( "Options:\n" );
@@ -100,10 +100,11 @@ void show_help() throw()
 
 void show_version() throw()
   {
-  std::printf( "%s version %s\n", program_name, PROGVERSION );
+  std::printf( "%s %s\n", Program_name, PROGVERSION );
   std::printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
-  std::printf( "This program is free software; you may redistribute it under the terms of\n" );
-  std::printf( "the GNU General Public License.  This program has absolutely no warranty.\n" );
+  std::printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n" );
+  std::printf( "This is free software: you are free to change and redistribute it.\n" );
+  std::printf( "There is NO WARRANTY, to the extent permitted by law.\n" );
   }
 
 } // end namespace
